==> PDCurses-2.8.tar.gz: PDCurses-2.8/demos/ptest.c <==
/*+-------------------------------------------------------------------------
	$Id: ptest.c,v 1.19 2006/03/29 19:50:13 wmcbrine Exp $
--------------------------------------------------------------------------*/

#include <curses.h>
#include <panel.h>
#include <stdlib.h>

PANEL *p1, *p2, *p3, *p4, *p5;
WINDOW *w1, *w2, *w3, *w4, *w5;

long nap_msec = 1;

char *mod[] = 
{
	"test ", "TEST ", "(**) ", "*()* ", "<--> ", "LAST "
};

PANEL *mkpanel(int, int, int, int);
void fill_panel(PANEL *);
void pflush(void);
void wait_a_while(long);
void saywhat(const char *);
void rmpanel(PANEL *);

/*+-------------------------------------------------------------------------
	wait_a_while(msec)
--------------------------------------------------------------------------*/
void wait_a_while(long msec)
{
	/* timeout(msec); */
	getch();
}

/*+-------------------------------------------------------------------------
	saywhat(text)
--------------------------------------------------------------------------*/
void saywhat(const char *text)
{
	wmove(stdscr, LINES - 1, 0);
	wprintw(stdscr, "%-20.20s", text);
}

/*+-------------------------------------------------------------------------
  mkpanel(rows, cols, tly, tlx) - alloc a win and panel and associate them
--------------------------------------------------------------------------*/
PANEL *mkpanel(int rows, int cols, int tly, int tlx)
{
	WINDOW *win = newwin(rows, cols, tly, tlx);
	PANEL *pan = (PANEL *)0;

	if (win)
	{
		pan = new_panel(win);

		if (!pan)
			delwin(win);
	}

	return pan;
}

/*+-------------------------------------------------------------------------
	rmpanel(pan)
--------------------------------------------------------------------------*/
void rmpanel(PANEL *pan)
{
	WINDOW *win = pan->win;

	del_panel(pan);
	delwin(win);
}

/*+-------------------------------------------------------------------------
	pflush()
--------------------------------------------------------------------------*/
void pflush(void)
{
	update_panels();
	doupdate();
}

/*+-------------------------------------------------------------------------
	fill_panel(win)
--------------------------------------------------------------------------*/
void fill_panel(PANEL *pan)
{
	WINDOW *win = pan->win;
	char num = *((char *)pan->user + 1);
	int y, x, maxy, maxx;

	box(win, 0, 0);  
	wmove(win, 1, 1);
	wprintw(win, "-pan%c-", num);
	getmaxyx(win, maxy, maxx);

	for (y = 2; y < maxy - 1; y++)
		for (x = 1; x < maxx - 1; x++)
		{
			wmove(win, y, x);
			waddch(win, num);
		}
}

/*+-------------------------------------------------------------------------
	main(argc,argv)
--------------------------------------------------------------------------*/
int main(int argc, char **argv)
{
	int itmp, y,x;

	if ((argc > 1) && atol(argv[1]))
		nap_msec = atol(argv[1]);

#ifdef XCURSES
	Xinitscr(argc, argv);
#else
	initscr();
#endif

	for (y = 0; y < LINES - 1; y++)
		for (x = 0; x < COLS; x++)
			wprintw(stdscr, "%d", (y + x) % 10);

	for (y = 0; y < 5; y++)
	{
		p1 = mkpanel(10, 10, 0, 0);
		w1 = panel_window(p1);
		set_panel_userptr(p1, "p1");

		p2 = mkpanel(14, 14, 5, 5);
		w2 = panel_window(p2);
		set_panel_userptr(p2, "p2");

		p3 = mkpanel(6, 8, 12, 12);
		w3 = panel_window(p3);
		set_panel_userptr(p3, "p3");

		p4 = mkpanel(10, 10, 10, 30);
		w4 = panel_window(p4);
		set_panel_userptr(p4, "p4");

		p5 = mkpanel(10, 10, 13, 37);
		w5 = panel_window(p5);
		set_panel_userptr(p5, "p5");

		fill_panel(p1);
		fill_panel(p2);
		fill_panel(p3);
		fill_panel(p4);
		fill_panel(p5);
		hide_panel(p4);
		hide_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("h3 s1 s2 s4 s5;");
		move_panel(p1, 0, 0);
		hide_panel(p3);
		show_panel(p1);
		show_panel(p2);
		show_panel(p4);
		show_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s1;");
		show_panel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s2;");
		show_panel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("m2;");
		move_panel(p2, 10, 10);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s3;");
		show_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("m3;");
		move_panel(p3, 5, 5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("b3;");
		bottom_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s4;");
		show_panel(p4);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s5;");
		show_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t3;");
		top_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t1;");
		top_panel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t2;");
		top_panel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t3;");
		top_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t4;");
		top_panel(p4);
		pflush();
		wait_a_while(nap_msec);

		for (itmp = 0; itmp < 6; itmp++)
		{
			saywhat("m4;");
			wmove(w4, 3, 1);
			waddstr(w4, mod[itmp]);
			move_panel(p4, 4, itmp * 10);
			wmove(w5, 4, 1);
			waddstr(w5, mod[itmp]);
			pflush();
			wait_a_while(nap_msec);
			saywhat("m5;");
			wmove(w4, 4, 1);
			waddstr(w4, mod[itmp]);
			move_panel(p5, 7, itmp * 10 + 6);
			wmove(w5, 3, 1);
			waddstr(w5, mod[itmp]);
			pflush();
			wait_a_while(nap_msec);
		}

		saywhat("m4;");
		move_panel(p4, 4, itmp * 10);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t5;");
		top_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t2;");
		top_panel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t1;");
		top_panel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d2;");
		rmpanel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("h3;");
		hide_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d1;");
		rmpanel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d4; ");
		rmpanel(p4);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d5; ");
		rmpanel(p5);
		pflush();
		wait_a_while(nap_msec);

		if (nap_msec == 1)
			break;

		nap_msec = 100L;
	}

	endwin();

	return 0;
}	/* end of main */

/* end of ptest.c */

==> PDCurses-3.2.tar.gz: PDCurses-3.2/demos/ptest.c <==
/*----------------------------------------------------------------------*
 *	$Id: ptest.c,v 1.20 2006/06/02 02:52:54 wmcbrine Exp $		*
 *----------------------------------------------------------------------*/

#include <curses.h>
#include <panel.h>
#include <stdlib.h>

PANEL *p1, *p2, *p3, *p4, *p5;
WINDOW *w1, *w2, *w3, *w4, *w5;

long nap_msec = 1;

char *mod[] = 
{
	"test ", "TEST ", "(**) ", "*()* ", "<--> ", "LAST "
};

void wait_a_while(long msec)
{
	/* timeout(msec); */
	getch();
}

void saywhat(const char *text)
{
	wmove(stdscr, LINES - 1, 0);
	wprintw(stdscr, "%-20.20s", text);
}

/*----------------------------------------------------------------------*
 *	mkpanel - alloc a win and panel and associate them		*
 *----------------------------------------------------------------------*/

PANEL *mkpanel(int rows, int cols, int tly, int tlx)
{
	WINDOW *win = newwin(rows, cols, tly, tlx);
	PANEL *pan = (PANEL *)0;

	if (win)
	{
		pan = new_panel(win);

		if (!pan)
			delwin(win);
	}

	return pan;
}

void rmpanel(PANEL *pan)
{
	WINDOW *win = pan->win;

	del_panel(pan);
	delwin(win);
}

void pflush(void)
{
	update_panels();
	doupdate();
}

void fill_panel(PANEL *pan)
{
	WINDOW *win = pan->win;
	char num = *((char *)pan->user + 1);
	int y, x, maxy, maxx;

	box(win, 0, 0);  
	wmove(win, 1, 1);
	wprintw(win, "-pan%c-", num);
	getmaxyx(win, maxy, maxx);

	for (y = 2; y < maxy - 1; y++)
		for (x = 1; x < maxx - 1; x++)
		{
			wmove(win, y, x);
			waddch(win, num);
		}
}

int main(int argc, char **argv)
{
	int itmp, y,x;

	if ((argc > 1) && atol(argv[1]))
		nap_msec = atol(argv[1]);

#ifdef XCURSES
	Xinitscr(argc, argv);
#else
	initscr();
#endif

	for (y = 0; y < LINES - 1; y++)
		for (x = 0; x < COLS; x++)
			wprintw(stdscr, "%d", (y + x) % 10);

	for (y = 0; y < 5; y++)
	{
		p1 = mkpanel(10, 10, 0, 0);
		w1 = panel_window(p1);
		set_panel_userptr(p1, "p1");

		p2 = mkpanel(14, 14, 5, 5);
		w2 = panel_window(p2);
		set_panel_userptr(p2, "p2");

		p3 = mkpanel(6, 8, 12, 12);
		w3 = panel_window(p3);
		set_panel_userptr(p3, "p3");

		p4 = mkpanel(10, 10, 10, 30);
		w4 = panel_window(p4);
		set_panel_userptr(p4, "p4");

		p5 = mkpanel(10, 10, 13, 37);
		w5 = panel_window(p5);
		set_panel_userptr(p5, "p5");

		fill_panel(p1);
		fill_panel(p2);
		fill_panel(p3);
		fill_panel(p4);
		fill_panel(p5);
		hide_panel(p4);
		hide_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("h3 s1 s2 s4 s5;");
		move_panel(p1, 0, 0);
		hide_panel(p3);
		show_panel(p1);
		show_panel(p2);
		show_panel(p4);
		show_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s1;");
		show_panel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s2;");
		show_panel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("m2;");
		move_panel(p2, 10, 10);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s3;");
		show_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("m3;");
		move_panel(p3, 5, 5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("b3;");
		bottom_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s4;");
		show_panel(p4);
		pflush();
		wait_a_while(nap_msec);

		saywhat("s5;");
		show_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t3;");
		top_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t1;");
		top_panel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t2;");
		top_panel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t3;");
		top_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t4;");
		top_panel(p4);
		pflush();
		wait_a_while(nap_msec);

		for (itmp = 0; itmp < 6; itmp++)
		{
			saywhat("m4;");
			wmove(w4, 3, 1);
			waddstr(w4, mod[itmp]);
			move_panel(p4, 4, itmp * 10);
			wmove(w5, 4, 1);
			waddstr(w5, mod[itmp]);
			pflush();
			wait_a_while(nap_msec);
			saywhat("m5;");
			wmove(w4, 4, 1);
			waddstr(w4, mod[itmp]);
			move_panel(p5, 7, itmp * 10 + 6);
			wmove(w5, 3, 1);
			waddstr(w5, mod[itmp]);
			pflush();
			wait_a_while(nap_msec);
		}

		saywhat("m4;");
		move_panel(p4, 4, itmp * 10);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t5;");
		top_panel(p5);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t2;");
		top_panel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("t1;");
		top_panel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d2;");
		rmpanel(p2);
		pflush();
		wait_a_while(nap_msec);

		saywhat("h3;");
		hide_panel(p3);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d1;");
		rmpanel(p1);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d4; ");
		rmpanel(p4);
		pflush();
		wait_a_while(nap_msec);

		saywhat("d5; ");
		rmpanel(p5);
		pflush();
		wait_a_while(nap_msec);

		if (nap_msec == 1)
			break;

		nap_msec = 100L;
	}

	endwin();

	return 0;
}	/* end of main */

/* end of ptest.c */
